@@ -17,7 +17,7 @@ def store():
     """
     pass
 
-def calculate(band_nir, band_green, ground_sampling_distance):
+def calculate(band_green, band_nir, ground_sampling_distance):
     """
     Function for calculating the CIGreen
     
