@@ -18,7 +18,7 @@ def store():
     """
     pass
 
-def calculate(band_nir, band_red_edge, ground_sampling_distance):
+def calculate(band_red_edge, band_nir, ground_sampling_distance):
     """
     Function for calculating the NDRE
     
